<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class ADXAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'AdEx Network (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'adx-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ADX';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#1B75BC';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x6bfF4Fb161347ad7de4A625AE5aa3A1CA7077819';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x4E3F30F7b7C6f0699164baEFAE60c36E985F2F20';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/adx.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "adx-net";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}