<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class AIOZAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'AIOZ Network (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'aioz-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'AIOZ';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#1B58EB';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x33d08D8C7a168333a85285a68C0042b39fC3741D';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xB428de5757fDcE9bD045891DFaFaD9A73e3333C2';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/aioz.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "aioz-network";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}