<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class ALICEAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'ALICE (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'alice-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 6;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ALICE';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#EA8397';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xAC51066d7bEC65Dc4589368da368b212745d63E8';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x714c7B5fBa92587DB658021C92395800b7db6954';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/alice.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "myneighboralice";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}