<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class ALPACAAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'AlpacaToken (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'alpaca-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ALPACA';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#31C67E';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x8F0528cE5eF7B51152A59745bEfDD91D97091d2F';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x9da18dc0F67fe8979F3C5c8a04949bbc6276bC6e';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/alpaca.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "alpaca-finance";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}