<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class AMPLAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'AMPL secured by Meter Passport (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'ampl-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'AMPL';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#31FFA8';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xDB021b1B247fe2F1fa57e0A87C748Cc1E321F07F';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x8b6fadB0B5119d94F0FE177D5832de41A34B2B16';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/ampl.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "ampleforth";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}