<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class ANYAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Anyswap (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'any-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ANY';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#6464F6';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xF68C9Df95a18B2A5a5fa1124d79EEEffBaD0B6Fa';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x19c67e66777db03DBDDC4B76482765ff17F55CCf';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/any.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "anyswap";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(0.1);
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}