<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class BCHAdapter extends  AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg Bitcoin Cash Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'bch-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'BCH';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#0AC18E';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x8fF795a6F4D97E7887C79beA79aba5cc76444aDf';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x7219f70E6725876D3d5062f52683261e64949CD8';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/bch.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "bitcoin-cash";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(0.01);
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}