<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class BTCBAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg Bitcoin BEP2 Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'btcb-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'BTCB';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#F7931A';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x7130d2A12B9BCbFAe4f2634d864A1Ee1Ce3Ead9c';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xd4F04606fCcaF4a6c2560B768aE5405923069015';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/btc.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "bitcoin-bep2";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(0.00001);
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}