<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class BTTAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'BitTorrent Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'btt-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 4;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'BTT';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#8329FF';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x352Cb5E19b12FC216548a2677bD0fce83BaE434B';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xB05d0F62CA9727bca586dEb8629Ade0c3B35750D';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/btt.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "blocktrade";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000000);
    }
}