<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class BTTPAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg BitTorrent Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'btt-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 4;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'BTT';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#8329FF';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x8595F9dA7b868b1822194fAEd312235E43007b49';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xdEc0a7271Ddc8763AAC9544f11058dd42587E413';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/btt.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "blocktrade";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000000);
    }
}