<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class CEEKAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'CEEK (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'ceek-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'CEEK';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#F0E15C';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xe0F94Ac5462997D2BC57287Ac3a3aE4C31345D66';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xdaa6e6fd19922dEA4580460077B1a87E5b3aA02b';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/ceek.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "ceek-vr";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}