<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class CELRAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg Celer Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'celr-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'CELR';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#66BFFF';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x1f9f6a696C6Fd109cD3956F45dC709d2b3902163';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x9b1B539C665A38B3F47A642aFCc477a9eF858B4a';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/celr.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "celer-network";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}