<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class CTKAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'CertiK Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'ctk-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'CTK';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#E1AA4C';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xA8c2B8eec3d368C0253ad3dae65a5F2BBB89c929';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x73b880D77287cC1B64C0ef2c79859c89CFBafc7f';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/ctk.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "certik";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}