<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class DAIAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg Dai Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'dai-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'DAI';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#F5AC37';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x1AF3F329e8BE154074D8769D1FFa4eE058B1DBc3';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x5625586868be4BBE3902682a4fAe57bdc2199Cd0';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/dai.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "multi-collateral-dai";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}