<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class DIAAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'DIAToken (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'dia-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'DIA';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#6A4EAB';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x99956D38059cf7bEDA96Ec91Aa7BB2477E0901DD';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x72BFCb5Fb2191a7E32c1A562a0C803250DE11fcA';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/dia.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "dia";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}