<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class ELFAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg ELF Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'elf-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ELF';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#2B5EBA';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xa3f020a5C92e15be13CAF0Ee5C95cF79585EeCC9';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x9a81896A54fe21C3eec7e88C5b204727C8f94CcB';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/elf.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "aelf";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}