<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class FRAXAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Frax (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'frax-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'FRAX';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#C915FF';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x90C97F71E18723b0Cf0dfa30ee176Ab653E89F40';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x89334Cfdb7Af933E8D7661e748CC737fae5f2a00';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/frax.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "frax";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}