<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class FREEAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'FREEdom Coin (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'free-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 8;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'FREE';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#FAE593';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x12e34cDf6A031a10FE241864c32fB03a4FDaD739';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x896EdBFA1cc2Af5380C58327EaBc5ba19AeCbDCD';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/free.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "free-coin";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000000000);
    }
}