<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class FRONTAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Frontier Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'front-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'FRONT';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#46322E';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x928e55daB735aa8260AF3cEDadA18B5f70C72f1b';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x7Ab949D6B6666125F4A60A3402F69AA9EAE8F591';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/front.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "frontier";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}