<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class IOTXAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg IoTeX Network (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'iotx-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'IOTX';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#00D4D5';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x9678E42ceBEb63F23197D726B29b1CB20d0064E5';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x8945c0fB7C35bEd9E4AE2Cdd2aA9b0412C1Aa5f6';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/iotx.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "iotex";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}