<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class JSTAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'JUST (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'jst-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'JST';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#B41514';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xeA998D307ACA04D4f0A3B3036Aba84AE2E409C0A';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xf927237192127B6e87b99edaf7fCf73728345C07';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/jst.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "just";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}