<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class LINAAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Linear Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'lina-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 4;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'LINA';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#0B0AFE';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x762539b45A1dCcE3D36d080F74d1AED37844b878';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xC001f2aa1FA1b5d5E77F3C91c099a5D14bd242fF';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/lina.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "linear";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000000);
    }
}