<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class LTOAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'LTO Network (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'lto-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'LTO';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#9E8FFB';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x857B222Fc79e1cBBf8Ca5f78CB133d1b7CF34BBd';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x879CF2190ee8FCF0f9C4a6cA1269D47eA8E9666E';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/lto.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "lto-network";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}