<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class MDTAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Measurable Data Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'mdt-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'MDT';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#4187F7';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x668DB7aa38eaC6B40c9D13dBE61361DC4c4611d1';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x2F2fa93997Bad99A629B79B1E9D31C72D9C80964';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/mdt.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "measurable-data-token";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}