<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class MTRGAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Wrapped MTRG on BSC by Meter.io (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'mtrg-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'MTRG';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#18275B';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xBd2949F67DcdC549c6Ebe98696449Fa79D988A9F';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x78a29322226c443CaF8075AfDcb53606E47c4afd';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/mtrg.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "meter-governance";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(0.1);
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}