<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class NRVAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Nerve Finance (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'nrv-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 4;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'NRV';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#7751E2';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x42F6f551ae042cBe50C739158b4f0CAC0Edb9096';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xbE3a43d61Aa61D9E8bb3B67a1B1967bbF5a3A553';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/nrv.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "nerve-finance";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000000);
    }
}