<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class RACAAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Radio Caca V2 (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'raca-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 5;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'RACA';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#FBC33C';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x12BB890508c125661E03b09EC06E404bc9289040';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x2A92f3e1F0E576D1240D34F71E6D95C87DF4E497';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/raca.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "radio-caca";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000000);
    }
}