<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class SDAOAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Singularity Dao (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'sdao-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'SDAO';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#E1710C';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x90Ed8F1dc86388f14b64ba8fb4bbd23099f18240';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xeA43f0A036533B35a583d7C2236E98300c9c01d4';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/sdao.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "singularitydao";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}