<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class SHIBAdapter extends AbstractBinanceTokenAdapter

{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg SHIBA INU Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'shib-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 6;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'SHIB';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#FFA409';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x2859e4544C4bB03966803b044A93563Bd2D0DD4D';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x30aF6569D86325d3e1c69c0c0A4500375a003796';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/shib.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "shiba-inu";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000000);
    }
}