<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class USDCAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg USD Coin (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'usdc-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'USDC';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#2775CA';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x8AC76a51cc950d9822D68b83fE1Ad97B32Cd580d';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x1a4B062D1F11744B511756D39F0C166bE00cBcdC';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/usdc.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "usd-coin";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}