<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class USDPAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg Pax Dollar Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'usdp-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 2;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'USDP';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#BAD147';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xb3c11196A4f3b1da7c23d9FB0A3dDE9c6340934F';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xf50F1918B77F77c008B1e6FE1F66eAD4Dc874798';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/usdp.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "paxos-standard";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(10000000);
    }
}