<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class USTCAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Wrapped USTC Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'ustc-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'USTC';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#5392F6';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x23396cF899Ca06c4472205fC903bDB4de249D6fC';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0x1aC9C958CD5feA7970DEFa9ccdA5425CdA969974';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/ustc.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "terrausd";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(100000000);
    }
}