<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class XECAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Binance-Peg eCash Token (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'xec-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 6;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'XEC';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#0D5FB4';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0x0Ef2e7602adD1733Bfdb17aC3094d0421B502cA3';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xA5a4484aDF71164Ea5d4030a3a5AF252777c522F';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/xec.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "ecash";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000000);
    }
}