<?php

namespace App\Plugins\BinanceBundle;

use App\CoinAdapters\Abstracts\AbstractBinanceTokenAdapter;
use Brick\Math\BigDecimal;

class ZILAdapter extends AbstractBinanceTokenAdapter
{
    /**
     * {@inheritDoc}
     */
    protected string $name = 'Zilliqa (BEP)';

    /**
     * {@inheritDoc}
     */
    protected string $identifier = 'zil-bep';

    /**
     * {@inheritDoc}
     */
    protected string $baseUnit = '1000000000000';

    /**
     * {@inheritDoc}
     */
    protected int $precision = 8;

    /**
     * {@inheritDoc}
     */
    protected int $currencyPrecision = 3;

    /**
     * {@inheritDoc}
     */
    protected string $symbol = 'ZIL';

    /**
     * {@inheritDoc}
     */
    protected bool $symbolFirst = true;

    /**
     * {@inheritDoc}
     */
    protected string $color = '#49C1BF';

    /**
     * {@inheritDoc}
     */
    protected string $contract = '0xb86AbCb37C3A4B64f74f59301AFF131a1BEcC787';

    /**
     * {@inheritDoc}
     */
    protected string $testContract = '0xC74E9a22337a1AAe82E2D7bc8ce75d810705A0c7';

    /**
     * {@inheritDoc}
     */
    public function getSvgIcon(): string
    {
        return asset('coin/binance-bundle/zil.svg');
    }

    /**
     * {@inheritDoc}
     */
    public function marketId(): string
    {
        return "zilliqa";
    }

    /**
     * {@inheritDoc}
     */
    public function getMinimumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit());
    }

    /**
     * {@inheritDoc}
     */
    public function getMaximumTransferable(): string
    {
        return (string) BigDecimal::of($this->getBaseUnit())->multipliedBy(1000000000);
    }
}